@@ -1,12 +1,11 @@
 import abc
-import types
 import typing
 import anchor.builtins as builtins
 import anchor.symtable as symtable
 import anchor.factory as factory
 
 
-__all__: list[str] = []
+__all__: typing.List[str] = list()
 
 
 class ASTNode(abc.ABC):
@@ -56,11 +55,11 @@ class Statement(ASTNode):
 
 class Block(ASTNode):
 
-    def __init__(self, statements: list[Statement]):
-        self.__statements: list[Statement] = statements
+    def __init__(self, statements: typing.List[Statement]) -> None:
+        self.__statements: typing.List[Statement] = statements
 
     @property
-    def statements(self) -> list[Statement]:
+    def statements(self) -> typing.List[Statement]:
         return self.__statements
 
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
@@ -77,7 +76,7 @@ class Block(ASTNode):
 
 class Program(ASTNode):
 
-    def __init__(self, block: Block):
+    def __init__(self, block: Block) -> None:
         self.__block: Block = block
 
     @property
@@ -91,7 +90,7 @@ class Program(ASTNode):
 
 class Name(Expression):
 
-    def __init__(self, identifier: str):
+    def __init__(self, identifier: str) -> None:
         self.__identifier: str = identifier
 
     @property
@@ -106,7 +105,7 @@ class Name(Expression):
 
 class Assignment(Statement):
 
-    def __init__(self, name: Name, expression: Expression):
+    def __init__(self, name: Name, expression: Expression) -> None:
         self.__name: Name = name
         self.__expression: Expression = expression
 
@@ -121,14 +120,18 @@ class Assignment(Statement):
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
         identifier: str = self.name.identifier
         astnode = self.expression.evaluate(st)
-        astnodes: list[ASTNode] = list([astnode])
-        st.insert(identifier, astnodes)
+        astnodes: typing.List[ASTNode] = list([astnode])
+        symbol = st.lookup(identifier)
+        if (symbol and symbol.kwargs.get('isproperty', False)):
+            symbol.symtable.insert(identifier, astnodes)
+        else:
+            st.insert(identifier, astnodes)
         return None
 
 
 class Break(Statement):
 
-    def __init__(self, literal: str):
+    def __init__(self, literal: str) -> None:
         self.__literal: str = literal
 
     @property
@@ -142,7 +145,7 @@ class Break(Statement):
 
 class Continue(Statement):
     
-    def __init__(self, literal: str):
+    def __init__(self, literal: str) -> None:
         self.__literal: str = literal
 
     @property
@@ -159,7 +162,9 @@ class Return(Statement, Atom):
     __expression: Expression = None
     __value: builtins.Type = None
 
-    def __init__(self, expression: Expression = None, value: builtins.Type = None):
+    def __init__(
+        self, expression: Expression = None, value: builtins.Type = None
+    ) -> None:
         self.__expression = expression
         self.__value = value
 
@@ -183,9 +188,9 @@ class Return(Statement, Atom):
 
 class Elif(Statement):
 
-    def __init__(self, 
-        expression: Expression, block: Block, elseblock: Block = None
-    ):
+    def __init__(
+        self, expression: Expression, block: Block, elseblock: Block = None
+    ) -> None:
         self.__expression: Expression = expression
         self.__block: Block = block
         self.__elseblock: Block = elseblock
@@ -211,11 +216,11 @@ class If(Statement):
 
     def __init__(
         self, expression: Expression, block: Block, 
-        elifs: list[Elif] = list(), elseblock: Block = None
-    ):
+        elifs: typing.List[Elif] = list(), elseblock: Block = None
+    ) -> None:
         self.__expression: Expression = expression
         self.__block: Block = block
-        self.__elifs: list[Elif] = elifs
+        self.__elifs: typing.List[Elif] = elifs
         self.__elseblock: Block = elseblock
 
     @property
@@ -227,7 +232,7 @@ class If(Statement):
         return self.__block
 
     @property
-    def elifs(self) -> list[Elif]:
+    def elifs(self) -> typing.List[Elif]:
         return self.__elifs
 
     @property
@@ -257,7 +262,9 @@ class If(Statement):
 
 class Iterate(Statement):
 
-    def __init__(self, iterable: Expression, variable: Name, block: Block):
+    def __init__(
+        self, iterable: Expression, variable: Name, block: Block
+    ) -> None:
         self.__iterable: Expression = iterable
         self.__variable: Name = variable
         self.__block: Block = block
@@ -279,7 +286,7 @@ class Iterate(Statement):
         for item in self.iterable.evaluate(st):
             itemnode: ASTNode = item
             astnode: ASTNode = itemnode.evaluate(st)
-            astnodes: list[ASTNode] = list([astnode])
+            astnodes: typing.List[ASTNode] = list([astnode])
             st.insert(identifier, astnodes)
             astnode: ASTNode = self.block.evaluate(st)
             if (isinstance(astnode, Return)):
@@ -293,7 +300,7 @@ class Iterate(Statement):
 
 class Loop(Statement):
 
-    def __init__(self, expression: Expression, block: Block):
+    def __init__(self, expression: Expression, block: Block) -> None:
         self.__expression: Expression = expression
         self.__block: Block = block
 
@@ -323,7 +330,7 @@ class Annotation(Statement, Atom):
 
     __value: builtins.Annotation = None
 
-    def __init__(self, literal: typing.Any):
+    def __init__(self, literal: typing.Any) -> None:
         self.__literal: typing.Any = literal
 
     @property
@@ -342,7 +349,7 @@ class Annotation(Statement, Atom):
 
 class Parameter(Statement):
 
-    def __init__(self, name: Name, typename: Name = None):
+    def __init__(self, name: Name, typename: Name = None) -> None:
         self.__name: Name = name
         self.__typename: Name = typename
 
@@ -365,19 +372,20 @@ class FunctionDef(Statement, Atom, Callable):
     __value: builtins.Function = None
 
     def __init__(
-        self, name: Name, parameters: list[Parameter], block: Block, **kwargs
-    ):
+        self, name: Name, parameters: typing.List[Parameter], block: Block, 
+        **kwargs
+    ) -> None:
         self.__name: Name = name
-        self.__parameters: list[Parameter] = parameters
+        self.__parameters: typing.List[Parameter] = parameters
         self.__block: Block = block
-        self.__kwargs: dict[str, typing.Any] = kwargs
+        self.__kwargs: typing.Dict[str, typing.Any] = kwargs
 
     @property
     def name(self) -> Name:
         return self.__name
 
     @property
-    def parameters(self) -> list[Parameter]:
+    def parameters(self) -> typing.List[Parameter]:
         return self.__parameters
 
     @property
@@ -385,7 +393,7 @@ class FunctionDef(Statement, Atom, Callable):
         return self.__block
 
     @property
-    def kwargs(self) -> dict[str, typing.Any]:
+    def kwargs(self) -> typing.Dict[str, typing.Any]:
         return self.__kwargs
 
     @property
@@ -393,9 +401,9 @@ class FunctionDef(Statement, Atom, Callable):
         return self.__value
 
     def call(
-        self, arguments: list[Expression], parentst: symtable.SymbolTable
+        self, arguments: typing.List[Expression], parentst: symtable.SymbolTable
     ) -> ASTNode:
-        parameters: list[Parameter] = self.parameters
+        parameters: typing.List[Parameter] = self.parameters
         block: Block = self.block
         functionst: symtable.Function = factory.SYMTABLE.new(
             symtable.Type.FUNCTION, 
@@ -408,14 +416,14 @@ class FunctionDef(Statement, Atom, Callable):
             identifier: str = parameter.name.identifier
             argument: Expression = arguments[index]
             astnode: ASTNode = argument.evaluate(parentst)
-            astnodes: list[ASTNode] = list([astnode])
+            astnodes: typing.List[ASTNode] = list([astnode])
             functionst.insert(identifier, astnodes, isparameter=True)
         
         # Evaluate function block
         isbuiltin = self.kwargs.get('isbuiltin', False)
         if (isbuiltin):
-            functionpointer: types.FunctionType = self.kwargs.get('pointer')
-            args: dict[str, builtins.Type] = dict()
+            functionpointer: typing.Callable = self.kwargs.get('pointer')
+            args: typing.Dict[str, builtins.Type] = dict()
             for parameter in parameters:
                 value: builtins.Type = parameter.evaluate(functionst).value
                 args[parameter.name.identifier] = value
@@ -428,7 +436,7 @@ class FunctionDef(Statement, Atom, Callable):
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
         self.__value = builtins.Function()
         identifier: str = self.name.identifier
-        astnodes: list[ASTNode] = list([self])
+        astnodes: typing.List[ASTNode] = list([self])
         st.insert(identifier, astnodes)
         return self
 
@@ -437,16 +445,18 @@ class Property(Statement, Atom):
 
     __value: builtins.Property = None
 
-    def __init__(self, name: Name, annotations: list[Annotation]):
+    def __init__(
+        self, name: Name, annotations: typing.List[Annotation]
+    ) -> None:
         self.__name: Name = name
-        self.__annotations: list[Annotation] = annotations
+        self.__annotations: typing.List[Annotation] = annotations
 
     @property
     def name(self) -> Name:
         return self.__name
 
     @property
-    def annotations(self) -> list[Annotation]:
+    def annotations(self) -> typing.List[Annotation]:
         return self.__annotations
 
     @property
@@ -454,10 +464,10 @@ class Property(Statement, Atom):
         return self.__value
 
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
-        self.__value = builtins.Property()
+        self.__value = "DEBUG!!!"
         identifier: str = self.name.identifier
-        astnodes: list[ASTNode] = list([self])
-        st.insert(identifier, astnodes)
+        astnodes: typing.List[ASTNode] = list([self])
+        st.insert(identifier, astnodes, isproperty=True)
         return self
 
 
@@ -466,21 +476,21 @@ class MethodDef(Statement, Atom, Callable):
     __value: builtins.Method = None
 
     def __init__(
-        self, name: Name, parameters: list[Parameter], block: Block,
-        annotations: list[Annotation], **kwargs
-    ):
+        self, name: Name, parameters: typing.List[Parameter], block: Block,
+        annotations: typing.List[Annotation], **kwargs
+    ) -> None:
         self.__name: Name = name
-        self.__parameters: list[Parameter] = parameters
+        self.__parameters: typing.List[Parameter] = parameters
         self.__block: Block = block
-        self.__annotations: list[Annotation] = annotations
-        self.__kwargs: dict[str, typing.Any] = kwargs
+        self.__annotations: typing.List[Annotation] = annotations
+        self.__kwargs: typing.Dict[str, typing.Any] = kwargs
 
     @property
     def name(self) -> Name:
         return self.__name
 
     @property
-    def parameters(self) -> list[Parameter]:
+    def parameters(self) -> typing.List[Parameter]:
         return self.__parameters
 
     @property
@@ -488,11 +498,11 @@ class MethodDef(Statement, Atom, Callable):
         return self.__block
 
     @property
-    def annotations(self) -> list[Annotation]:
+    def annotations(self) -> typing.List[Annotation]:
         return self.__annotations
 
     @property
-    def kwargs(self) -> dict[str, typing.Any]:
+    def kwargs(self) -> typing.Dict[str, typing.Any]:
         return self.__kwargs
 
     @property
@@ -500,9 +510,9 @@ class MethodDef(Statement, Atom, Callable):
         return self.__value
 
     def call(
-        self, arguments: list[Expression], parentst: symtable.SymbolTable
+        self, arguments: typing.List[Expression], parentst: symtable.SymbolTable
     ) -> ASTNode:
-        parameters: list[Parameter] = self.parameters
+        parameters: typing.List[Parameter] = self.parameters
         block: Block = self.block
         methodst: symtable.Function = factory.SYMTABLE.new(
             symtable.Type.FUNCTION, 
@@ -513,9 +523,9 @@ class MethodDef(Statement, Atom, Callable):
         for index in range(len(parameters)):
             parameter: Parameter = parameters[index]
             identifier: str = parameter.name.identifier
-            astnodes: list[ASTNode] = list([
-                arguments[index].evaluate(parentst)
-            ])
+            argument: Expression = arguments[index]
+            astnode: ASTNode = argument.evaluate(parentst)
+            astnodes: typing.List[ASTNode] = list([astnode])
             methodst.insert(identifier, astnodes, isparameter=True)
         
         # Evaluate method block
@@ -525,8 +535,8 @@ class MethodDef(Statement, Atom, Callable):
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
         self.__value = builtins.Method()
         identifier: str = self.name.identifier
-        astnodes: list[ASTNode] = list([self])
-        st.insert(identifier, astnodes)
+        astnodes: typing.List[ASTNode] = list([self])
+        st.insert(identifier, astnodes, ismethod=True)
         return self
 
 
@@ -534,14 +544,17 @@ class ClassDef(Statement, Atom, Callable):
 
     __value: builtins.Class = None
 
-    def __init__(self, name: Name, block: Block, annotations: list[Annotation], **kwargs):
+    def __init__(
+        self, name: Name, block: Block, annotations: typing.List[Annotation], 
+        **kwargs
+    ) -> None:
         self.__name: Name = name
         self.__block: Block = block
-        self.__annotations: list[Annotation] = annotations
-        self.__kwargs: dict[str, typing.Any] = kwargs
+        self.__annotations: typing.List[Annotation] = annotations
+        self.__kwargs: typing.Dict[str, typing.Any] = kwargs
 
-        self.__properties: dict[str, Property] = dict()
-        self.__methods: dict[str, MethodDef] = dict()
+        self.__properties: typing.Dict[str, Property] = dict()
+        self.__methods: typing.Dict[str, MethodDef] = dict()
         for statement in self.__block.statements:
             if (isinstance(statement, Property)):
                 identifier = statement.name.identifier
@@ -566,19 +579,19 @@ class ClassDef(Statement, Atom, Callable):
         return self.__block
 
     @property
-    def kwargs(self) -> dict[str, typing.Any]:
+    def kwargs(self) -> typing.Dict[str, typing.Any]:
         return self.__kwargs
 
     @property
-    def properties(self) -> dict[str, Property]:
+    def properties(self) -> typing.Dict[str, Property]:
         return self.__properties
 
     @property
-    def methods(self) -> dict[str, MethodDef]:
+    def methods(self) -> typing.Dict[str, MethodDef]:
         return self.__methods
 
     @property
-    def annotations(self) -> list[Annotation]:
+    def annotations(self) -> typing.List[Annotation]:
         return self.__annotations
 
     @property
@@ -586,10 +599,10 @@ class ClassDef(Statement, Atom, Callable):
         return self.__value
 
     def call(
-        self, arguments: list[Expression], parentst: symtable.SymbolTable
+        self, arguments: typing.List[Expression], parentst: symtable.SymbolTable
     ) -> ASTNode:
-        properties: dict[str, Property] = self.properties
-        methods: dict[str, MethodDef] = self.methods
+        properties: typing.Dict[str, Property] = self.properties
+        methods: typing.Dict[str, MethodDef] = self.methods
         instancest: symtable.Class = factory.SYMTABLE.new(
             symtable.Type.CLASS, 
             identifier=self.name.identifier, parent=parentst,
@@ -597,21 +610,13 @@ class ClassDef(Statement, Atom, Callable):
 
         # Insert symbols for properties
         for _, prop in properties.items():
-            astnodes: list[ASTNode] = list([prop])
-            instancest.insert(
-                prop.name.identifier, astnodes, isproperty=True
-            )
+            prop.evaluate(instancest)
 
         # Insert symbols for methods
         for _, method in methods.items():
-            astnodes: list[ASTNode] = list([method])
-            instancest.insert(
-                method.name.identifier, astnodes, ismethod=True
-            )
+            method.evaluate(instancest)
 
         # Evaluate constructor
-        factorymethod: MethodDef = methods[self.name.identifier]
-        factorymethod.evaluate(instancest)
         call: Call = Call(Name(self.name.identifier), arguments)
         call.evaluate(instancest)
 
@@ -621,7 +626,7 @@ class ClassDef(Statement, Atom, Callable):
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
         self.__value = builtins.Class()
         identifier: str = self.name.identifier
-        astnodes: list[ASTNode] = list([self])
+        astnodes: typing.List[ASTNode] = list([self])
         st.insert(identifier, astnodes)
         return self
 
@@ -630,7 +635,7 @@ class Instance(Statement, Atom):
 
     __value: builtins.Instance = None
 
-    def __init__(self, classdef: ClassDef, instancest: symtable.Class):
+    def __init__(self, classdef: ClassDef, instancest: symtable.Class) -> None:
         self.__classdef: ClassDef = classdef
         self.__instancest = instancest
 
@@ -654,7 +659,7 @@ class Instance(Statement, Atom):
 
 class Or(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -676,7 +681,7 @@ class Or(Expression):
 
 class And(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -698,7 +703,7 @@ class And(Expression):
 
 class Not(Expression):
 
-    def __init__(self, right: Expression):
+    def __init__(self, right: Expression) -> None:
         self.__right: Expression = right
 
     @property
@@ -714,7 +719,7 @@ class Not(Expression):
 
 class EqEqual(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -736,7 +741,7 @@ class EqEqual(Expression):
 
 class NotEqual(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -758,7 +763,7 @@ class NotEqual(Expression):
 
 class Less(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -780,7 +785,7 @@ class Less(Expression):
 
 class LessEqual(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -802,7 +807,7 @@ class LessEqual(Expression):
 
 class Greater(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -824,7 +829,7 @@ class Greater(Expression):
 
 class GreaterEqual(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -846,7 +851,7 @@ class GreaterEqual(Expression):
 
 class Plus(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -868,7 +873,7 @@ class Plus(Expression):
 
 class Minus(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -890,7 +895,7 @@ class Minus(Expression):
 
 class Star(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -912,7 +917,7 @@ class Star(Expression):
 
 class DoubleStar(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -934,7 +939,7 @@ class DoubleStar(Expression):
 
 class Slash(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -956,7 +961,7 @@ class Slash(Expression):
 
 class DoubleSlash(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -978,7 +983,7 @@ class DoubleSlash(Expression):
 
 class Percent(Expression):
 
-    def __init__(self, left: Expression, right: Expression):
+    def __init__(self, left: Expression, right: Expression) -> None:
         self.__left: Expression = left
         self.__right: Expression = right
 
@@ -1000,7 +1005,7 @@ class Percent(Expression):
 
 class UPlus(Expression):
 
-    def __init__(self, right: Expression):
+    def __init__(self, right: Expression) -> None:
         self.__right: Expression = right
 
     @property
@@ -1016,7 +1021,7 @@ class UPlus(Expression):
 
 class UMinus(Expression):
 
-    def __init__(self, right: Expression):
+    def __init__(self, right: Expression) -> None:
         self.__right: Expression = right
 
     @property
@@ -1032,7 +1037,7 @@ class UMinus(Expression):
 
 class Boolean(Expression, Atom):
 
-    def __init__(self, value: bool):
+    def __init__(self, value: bool) -> None:
         self.__literal: str = str(value)
         self.__value: builtins.Boolean = builtins.Boolean(bool(value))
 
@@ -1054,7 +1059,7 @@ class Null(Expression, Atom):
     __literal: str = None
     __value: builtins.Null = None
 
-    def __init__(self, literal: str = None, value: str = None):
+    def __init__(self, literal: str = None, value: str = None) -> None:
         if (literal != None):
             self.__literal = literal
             self.__value = builtins.Null(str(self.literal))
@@ -1080,7 +1085,7 @@ class String(Expression, Atom, Iterable):
     __literal: str = None
     __value: builtins.String = None
 
-    def __init__(self, literal: str = None, value: str = None):
+    def __init__(self, literal: str = None, value: str = None) -> None:
         if (literal != None):
             self.__literal = literal
             self.__value = builtins.String(str(self.literal))
@@ -1118,7 +1123,7 @@ class Integer(Expression, Atom):
     __literal: str = None
     __value: builtins.Integer = None
 
-    def __init__(self, literal: str = None, value: int = None):
+    def __init__(self, literal: str = None, value: int = None) -> None:
         if (literal != None):
             self.__literal = literal
             self.__value = builtins.Integer(int(self.literal))
@@ -1144,7 +1149,7 @@ class Float(Expression, Atom):
     __literal: str = None
     __value: builtins.Float = None
 
-    def __init__(self, literal: str = None, value: float = None):
+    def __init__(self, literal: str = None, value: float = None) -> None:
         if (literal != None):
             self.__literal = literal
             self.__value = builtins.Float(float(self.literal))
@@ -1170,7 +1175,7 @@ class Complex(Expression, Atom):
     __literal: str = None
     __value: builtins.Complex = None
 
-    def __init__(self, literal: str = None, value: complex = None):
+    def __init__(self, literal: str = None, value: complex = None) -> None:
         if (literal != None):
             self.__literal = literal
             self.__value = builtins.Complex(complex(self.literal))
@@ -1193,21 +1198,20 @@ class Complex(Expression, Atom):
 
 class Tuple(Expression, Atom, Iterable):
 
-    __expressions: list[Expression] = None
+    __expressions: typing.List[Expression] = None
     __value: builtins.Tuple = None
 
     def __init__(
-        self, expressions: list[Expression] = None,
-        value: tuple = None 
-        
-    ):
+        self, expressions: typing.List[Expression] = None,
+        value: typing.Tuple = None
+    ) -> None:
         if (expressions != None):
-            self.__expressions: list[Expression] = expressions
+            self.__expressions: typing.List[Expression] = expressions
         elif (value != None):
             self.__value = builtins.Tuple(tuple(value))
 
     @property
-    def expressions(self) -> list[Expression]:
+    def expressions(self) -> typing.List[Expression]:
         return self.__expressions
 
     @property
@@ -1228,12 +1232,12 @@ class Tuple(Expression, Atom, Iterable):
     
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
         if (self.expressions != None):
-            atoms: list[Atom] = list([
+            atoms: typing.List[Atom] = list([
                 expression.evaluate(st)
                 for expression in self.expressions
             ])
             self.__value = builtins.Tuple(tuple(map(
-                lambda x: x.value, atoms,
+                lambda x: x.value, atoms
             )))
         elif (self.value != None):
             pass
@@ -1242,20 +1246,20 @@ class Tuple(Expression, Atom, Iterable):
 
 class List(Expression, Atom, Iterable):
     
-    __expressions: list[Expression] = None
+    __expressions: typing.List[Expression] = None
     __value: builtins.List = None
 
     def __init__(
-        self, expressions: list[Expression] = None,
-        value: list = None
-    ):
+        self, expressions: typing.List[Expression] = None,
+        value: typing.List = None
+    ) -> None:
         if (expressions != None):
-            self.__expressions: list[Expression] = expressions
+            self.__expressions: typing.List[Expression] = expressions
         elif (value != None):
             self.__value = builtins.List(list(value))
 
     @property
-    def expressions(self) -> list[Expression]:
+    def expressions(self) -> typing.List[Expression]:
         return self.__expressions
 
     @property
@@ -1276,12 +1280,12 @@ class List(Expression, Atom, Iterable):
     
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
         if (self.expressions != None):
-            atoms: list[Atom] = list([
+            atoms: typing.List[Atom] = list([
                 expression.evaluate(st)
                 for expression in self.expressions
             ])
             self.__value = builtins.List(list(map(
-                lambda x: x.value, atoms,
+                lambda x: x.value, atoms
             )))
         elif (self.value != None):
             pass
@@ -1290,20 +1294,21 @@ class List(Expression, Atom, Iterable):
 
 class Dict(Expression, Atom, Iterable):
 
-    __kvpairs: list[tuple[Expression, Expression]] = None
+    __kvpairs: typing.List[typing.Tuple[Expression, Expression]] = None
     __value: builtins.Dict = None
 
     def __init__(
-        self, kvpairs: list[tuple[Expression, Expression]] = None,
-        value: dict = None
-    ):
+        self, kvpairs: typing.List[typing.Tuple[Expression, Expression]] = None,
+        value: typing.Dict = None
+    ) -> None:
         if (kvpairs != None):
-            self.__kvpairs: list[tuple[Expression, Expression]] = kvpairs
+            self.__kvpairs: typing.List[typing.Tuple[Expression, Expression]] \
+                = kvpairs
         elif (value != None):
             self.__value = builtins.Dict(dict(value))
 
     @property
-    def kvpairs(self) -> list[tuple[Expression, Expression]]:
+    def kvpairs(self) -> typing.List[typing.Tuple[Expression, Expression]]:
         return self.__kvpairs
 
     @property
@@ -1324,12 +1329,12 @@ class Dict(Expression, Atom, Iterable):
 
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
         if (self.kvpairs != None):
-            atoms: dict[Atom, Atom] = dict({
+            atoms: typing.Dict[Atom, Atom] = dict({
                 k.evaluate(st): v.evaluate(st)
                 for k, v in self.kvpairs
             })
             self.__value = builtins.Dict(dict(map(
-                lambda item: (item[0].value, item[1].value), atoms.items(),
+                lambda item: (item[0].value, item[1].value), atoms.items()
             )))
         elif (self.value != None):
             pass
@@ -1338,7 +1343,7 @@ class Dict(Expression, Atom, Iterable):
 
 class DotName(Expression):
 
-    def __init__(self, expression: Expression, name: Name):
+    def __init__(self, expression: Expression, name: Name) -> None:
         self.__expression: Expression = expression
         self.__name: Name = name
 
@@ -1357,22 +1362,24 @@ class DotName(Expression):
 
 class Call(Expression):
 
-    def __init__(self, expression: Expression, arguments: list[Expression]):
+    def __init__(
+        self, expression: Expression, arguments: typing.List[Expression]
+    ) -> None:
         self.__expression: Expression = expression
-        self.__arguments: list[Expression] = arguments
+        self.__arguments: typing.List[Expression] = arguments
 
     @property
     def expression(self) -> Expression:
         return self.__expression
 
     @property
-    def arguments(self) -> list[Expression]:
+    def arguments(self) -> typing.List[Expression]:
         return self.__arguments
     
     def evaluate(self, st: symtable.SymbolTable) -> ASTNode:
         astnode: ASTNode = None
         if (isinstance(self.expression, Name)):
-            name = self.expression
+            name: Name = self.expression
             identifier: str = name.identifier
             astnode = st.lookup(identifier).astnode
         elif (isinstance(self.expression, DotName)):
@@ -1380,7 +1387,7 @@ class Call(Expression):
             instancename: Name = dotname.expression
             instance: Instance = st.lookup(instancename.identifier).astnode
             st = instance.instancest
-            name = dotname.name
+            name: Name = dotname.name
             identifier: str = name.identifier
             astnode = st.lookup(identifier).astnode
         else:
