@@ -1,5 +1,5 @@
-import inspect
 import typing
+import inspect
 import anchor.system as system
 import anchor.parse as parse
 import anchor.ast as ast
@@ -8,25 +8,25 @@ import anchor.builtins as builtins
 import anchor.factory as factory
 
 
-__all__: list[str] = ['execute',]
+__all__: typing.List[str] = list(['execute',])
 
 
 def execute(data: str) -> typing.Any:
     # Define main symbol table
-    mainidentifier = 'Main'
+    mainidentifier: typing.Literal = 'Main'
     symboltable: symtable.SymbolTable = factory.SYMTABLE.new(
-        symtable.Type.MAIN, identifier=mainidentifier,
+        symtable.Type.MAIN, identifier=mainidentifier
     )
 
     # Include builtin functions
     for identifier, functionpointer in builtins.FUNCTION.items():
         name = ast.Name(identifier)
-        parameters: list[ast.Parameter] = list([
+        parameters: typing.List[ast.Parameter] = list([
             ast.Parameter(ast.Name(argument))
             for argument in inspect.getfullargspec(functionpointer)[0]
         ])
         functiondef: ast.FunctionDef = ast.FunctionDef(
-            name, parameters, None, pointer=functionpointer, isbuiltin=True,
+            name, parameters, None, pointer=functionpointer, isbuiltin=True
         )
         functiondef.evaluate(symboltable)
     
@@ -34,7 +34,7 @@ def execute(data: str) -> typing.Any:
     parser: parse.AnchorParser = parse.AnchorParser(
         debuglex=system.GLOBAL.debuglex, 
         debugyacc=system.GLOBAL.debugyacc,
-        debuglog=system.GLOBAL.log,
+        debuglog=system.GLOBAL.logger
     )
     abstractsyntaxtree: ast.ASTNode = parser.parse(data)
     return abstractsyntaxtree.evaluate(symboltable)
